# eric7.VirtualEnv

Package implementing virtualenv related functionality.

### Modules

VirtualenvAddEditDialog | Module implementing a dialog to enter the data of a virtual environment.
VirtualenvConfigurationDialog | Module implementing a dialog to enter the parameters for the virtual environment.
VirtualenvExecDialog | Module implementing the virtualenv execution dialog.
VirtualenvInterpreterSelectionDialog | Module implementing a dialog to enter the interpreter for a virtual environment.
VirtualenvManager | Module implementing a class to manage Python virtual environments.
VirtualenvManagerWidgets | Module implementing a dialog to manage the list of defined virtual environments.
VirtualenvMeta | Module implementing a dataclass containing the metadata of a virtual environment.
VirtualenvNameDialog | Module implementing a dialog to enter the logical name for a new virtual environment.
VirtualenvUpgradeConfigurationDialog | Module implementing a dialog to enter the virtual environment upgrade parameters.
VirtualenvUpgradeExecDialog | Module implementing the virtualenv upgrade execution dialog.